<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\SmOperadorDataSoucerService;
use Teknisa\SM\Util\Utilities;


class SmOperadorDataSoucerController extends SMCrud {
    
    protected $dataSourceName = "descontoAcrescimo_Operador";
    protected $operadorService;
    protected $newCode;
    
    public function __construct($crudService, $environment, NewCode $newCode, SmOperadorDataSoucerService $operadorService,Utilities $utilities) {
        parent::__construct($crudService, $environment);
        $this->operadorService = $operadorService;
        $this->newCode = $newCode;
        $this->utilities = $utilities;
    }
   /**
    * A função "find" Busca os dados para a tela sem ou com filtro
    */
    public function find(Request\Filter $request, Response $response) {
        $filterData = $request->getFilterCriteria();
        $filtros = array();
        
        if (count($filterData->getConditions()) > 0) {
            foreach ($filterData->getConditions() as $filter) {
                if ($filter["columnName"] == "CDOPERADOR") {
                    $filtros["CDOPERADOR"] = $filter["value"];
                    
                }
                else if ($filter["columnName"] == "NRPERFILACESSO") {
                    $filtros["NRPERFILACESSO"] = $filter["value"];
                }
                else if ($filter["columnName"] == "NRPARCNEGOCIO") {
                    $filtros["NRPARCNEGOCIO"] = $filter["value"];
                }
                else if ($filter["columnName"] == "CDFILIAL") {
                    $filtros["CDFILIAL"] = $filter["value"];
                }
            }
        }
        $resultados = $this->operadorService->find($filtros);
        
        $todosresultados = new DataSet('RESULTADOS', $resultados);
        
        $response->addDataSet($todosresultados);
    }
    public function salvarOperacaoAcresOuDescont(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrparcnegocio   = $row["NRPARCNEGOCIO"];
            $cdservorcadesc   = $row["CDSERVORCADESC"];
            $vrpercdescdesc   = $row["VRPERCDESCDESC"];
            $idtipodesc   = $row["IDTIPODESC"];
            $cdservorcaacres   = $row["CDSERVORCAACRES"];
            $vrpercdescacres   = $row["VRPERCDESCACRES"];
            $idtipoacres   = $row["IDTIPOACRES"];
            $row               = $row["ROW"];
            $dataSource    = "fct_percdescoper_widget";
            $nrorg = $this->environment->getNrOrg();
            $cdoperinclusao = $this->environment->getCdOperador();
            $nrorginclusao   = $nrorg;
            $idativo   = "S";
            $pkFieldNames = ["NRSEQDESC"];
            $validationColumnsDesc = ["CDSERVORCADESC", "NRPARCNEGOCIO", "IDTIPODESC"];
            $validationColumnsAcres = ["CDSERVORCAACRES", "NRPARCNEGOCIO", "IDTIPOACRES"];
            $repetido = [];
            
            if($cdservorcadesc && $vrpercdescdesc){
                $inexisteDesc = $this->utilities->validateDuplicatedRecords($row, $dataSource, $pkFieldNames, $validationColumnsDesc);
                if(!$inexisteDesc)
                    array_push($repetido, "D");
            }   
            
            if($cdservorcaacres && $vrpercdescacres){        
                $inexisteAcres = $this->utilities->validateDuplicatedRecords($row, $dataSource, $pkFieldNames, $validationColumnsAcres);
                if(!$inexisteAcres)
                    array_push($repetido, "A");
            }
            
            if(count($repetido) == 0){
                if($cdservorcadesc && $vrpercdescdesc){
                    
                    $nrseqdesc = $this->newCode->getCodeByTableName("FCT_PERCDESCOPER", $nrorg, 1, 10, true);
                    $this->operadorService->salvarOperacaoAcresOuDescont($nrseqdesc, $nrparcnegocio, $nrorg, $cdservorcadesc, $vrpercdescdesc, $idtipodesc, $cdoperinclusao, $nrorginclusao, $idativo);
                }
                if($cdservorcaacres && $vrpercdescacres){
                    
                    $nrseqdesc = $this->newCode->getCodeByTableName("FCT_PERCDESCOPER", $nrorg, 1, 10, true);
                    $this->operadorService->salvarOperacaoAcresOuDescont($nrseqdesc, $nrparcnegocio, $nrorg, $cdservorcaacres, $vrpercdescacres, $idtipoacres, $cdoperinclusao, $nrorginclusao, $idativo);
                }
            }
            $resultadosRepetidos = new DataSet('TIPOREPEDITO', $repetido);
        
            $response->addDataSet($resultadosRepetidos);
        }
         catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
?>

